@@ -20,7 +20,7 @@ int main (int argc, char const *const *argv)
   int nl = 1 ;
   PROG = "dollarat" ;
   {
-    subgetopt_t l = SUBGETOPT_ZERO ;
+    subgetopt l = SUBGETOPT_ZERO ;
     for (;;)
     {
       int opt = subgetopt_r(argc, argv, "nd:0", &l) ;
